@@ -134,12 +134,11 @@ class Parse:
             return str.join(';',result)
 
     def format(self,info,previewimages,magnets):
-        detailinfo= {"id": "", "date": "", "runtime": 0, "javdblink":"","title":"","director": "", "directorlink": "", "studio": "", "studiolink": "",
-                     "tag": "", "taglink": "","genres": "","genreslink": "","actors": "","actorslink": "","rating":0.00,"ratingnum":0,
-                     "smallimage":"","bigimage":"","previewimages":"","magnets":""}
+        detailinfo= {"id": "", "date": "", "runtime": 0, "javdblink": "", "title": "", "director": "",
+                     "directorlink": "", "studio": "", "studiolink": "", "tag": "", "taglink": "", "genres": "",
+                     "genreslink": "", "actors": "", "actorslink": "", "rating": 0.00, "ratingnum": 0, "smallimage": "",
+                     "bigimage": "", "previewimages": "", "magnets": "", 'id': info['id'], 'date': info['date']}
 
-        detailinfo['id']=info['id']
-        detailinfo['date'] = info['date']
         if info['runtime']: detailinfo['runtime'] = int(info['runtime'])
         detailinfo['javdblink'] = info['link']
         detailinfo['title'] = info['title'].replace("'","").replace("\n","").replace("\t","").replace("\r","").replace(u"\xa0","")
@@ -179,7 +178,7 @@ class Parse:
             img=div.xpath("//img/@data-src")[0]
             tags='/'.join(div.xpath("//div[@class='tags has-addons']")[0].itertext()).replace("\n","").replace(" ","")
             d["uid"]=uid
-            d["title"] = title
+            d["title"] = title.replace("'","’")
             d["date"] = date
             d["javdb_link"] = javdb_link
             d["img"] = img
